pub trait Backend: Send + Sync {
// Required methods
fn name(&self) -> String;
fn fresh<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Target>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
}Expand description
A factory for stores under test.
Required Methods
Sourcefn fresh<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Target>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn fresh<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Target>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
A store containing nothing but an empty root directory.
Errors
Returns whatever the backend’s own provisioning fails with. A failure here is reported against the case that asked for it rather than aborting the run.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".